##################################################
#       {{step_name}}   Settings File
##################################################

## Set the global logging level to debug
# LOGGING_DEBUG = True

CONSUMER_CONFIG = {}
PRODUCER_CONFIG = {}
METRICS_CONFIG = {}
PROMETHEUS = False

## Step Configuration
STEP_CONFIG = {
    "CONSUMER_CONFIG": CONSUMER_CONFIG,
    "PRODUCER_CONFIG": PRODUCER_CONFIG,
    "METRICS_CONFIG": METRICS_CONFIG,
    "PROMETHEUS": PROMETHEUS,
}
